#ifndef GLOBAL
#define GLOBAL

extern Fold *top;
extern int levels;
extern int stop;
extern int smooth;
extern int cross;
extern int slope;
extern int snooze_time;
extern int request_clear;
extern int n_col;
extern int band_size;
extern int e_events;
extern float mix;
extern float midmix;
extern float fdim;
extern Height start;
extern Height mean;
extern Height varience;
extern Height shift;
extern Height delta_shadow;
extern float stretch;
extern float contour;
extern float ambient;
extern float contrast;
extern float vfract;
extern float altitude;
extern float distance;
extern double phi;
extern double alpha;
extern double shadow_slip;
extern double shadow_register;
extern double cos_phi;
extern double sin_phi;
extern double tan_phi;
extern double x_fact;
extern double y_fact;
extern Height sealevel;
extern Height forceheight;
extern int width;
extern int seed;
extern int height;
extern double vangle;
extern double tan_vangle;
extern float vscale;
extern float viewpos;
extern float viewheight;
extern float focal;
extern Height *shadow;
extern Height *a_strip, *b_strip;


#endif
